@@ -8,6 +8,8 @@
 #' @param adjust A logical value indicating whether to adjust timestamps to match the system timezone. Defaults to FALSE.
 #' @param verbose A logical value indicating whether to print detailed messages during the function's execution. Defaults to FALSE.
 #' @param auto.assign A logical value indicating whether to automatically assign the resulting object to the current environment. Defaults to TRUE.
+#' @param market A character string specifying type of market
+#' @param board A character string specifying type of board
 #' @param api.key A character string specifying the API key to use when retrieving data from Alor or Tinkoff. Defaults to "".
 #' @param env environment where the data will be assigned
 #'
@@ -20,20 +22,54 @@
 #' getOrderbook('BTC_USDT', src = 'poloniex')
 #' @export
 
-getOrderbook <- function #S3 function (Poloniex is a class of first argument)
+"getOrderbook" <- function #S3 function (Poloniex is a class of first argument)
 (Symbols,
  depth=10,
  src='poloniex',
  adjust=FALSE,
  verbose=FALSE,
  auto.assign=TRUE,
+ market = 'shares',
+ board = 'tqbr',
  api.key = '',
  env=globalenv())
 {
-  tryCatch(
-    {
+
 		src <- tolower(src)
 		Price <- Volume <- isAsk <- NULL
+
+
+		## choose exchange
+		if(src == 'moex')
+		{
+		  engine = ifelse(market == 'shares','stock','futures')
+		  if(market == 'forts') board = 'rfud'
+		  login <- Sys.getenv('MOEX_DATASHOP_LOGIN')
+		  password <- Sys.getenv('MOEX_DATASHOP_PASSWORD')
+		  cookie_value <- Sys.getenv('MOEX_DATASHOP_COOKIE')
+		  if(login == '' & password=='')
+		    return('authenticate to ISS Moex using login/password ')
+		  headers = c('Cookie' =  paste0('MicexPassportCert=',cookie_value))
+		  full_url <- sprintf('https://iss.moex.com/iss/engines/%s/markets/%s/boards/%s/securities/%s/orderbook.json',
+		                      engine,market, board, Symbols)
+		  response <- GET(full_url, encode = "json",add_headers(headers))
+		  if(response$status_code==200)
+		  {
+		    json_response <- content(response, "text", encoding = "UTF-8")
+		    json_response <- fromJSON(json_response)
+		    data_result = data.table(json_response$orderbook$data)
+		    if(nrow(data_result)>0)
+		    {
+		      setnames(data_result,json_response$orderbook$columns)
+		      for(col in c('PRICE', 'QUANTITY','SEQNUM'))
+		        set(data_result, j = col, value = as.numeric(data_result[[col]]))
+		    }
+		    return(data_result)
+		  }
+		  if(response$status_code!=200)
+		    if(verbose) return(content(response, as = "parsed"))
+		}
+
 	  ## choose exchange
 		if(src == 'tinkoff')
 		{
@@ -198,14 +234,4 @@ if (src == "xbtce")
         }
 
         return(orderbook)
-    },
-    #if an error occurs, tell me the error
-    error=function(e) {
-      message('Server not response - try later')
-      #print(e)
-    },
-    #if a warning occurs, tell me the warning
-    warning=function(w) {
-      message('Check your internet connection')
-    })
 }
